#
# spec file for package python-backports.ssl_match_hostname
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-backports.ssl_match_hostname
Version:        3.5.0.1
Release:        lp151.2.1
Summary:        The ssl.match_hostname() function from Python 3.5
License:        Python-2.0
Group:          Development/Languages/Python
Url:            http://bitbucket.org/brandon/backports.ssl_match_hostname
Source:         https://files.pythonhosted.org/packages/source/b/backports.ssl_match_hostname/backports.ssl_match_hostname-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module backports}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-backports
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%if %{python3_version_nodots} > 34
%define skip_python3 1
%endif

%python_subpackages

%description
The Secure Sockets layer is only actually *secure*
if you check the hostname in the certificate returned
by the server to which you are connecting,
and verify that it matches to hostname
that you are trying to reach.

But the matching logic, defined in `RFC2818`_,
can be a bit tricky to implement on your own.
So the ``ssl`` package in the Standard Library of Python 3.2
and greater now includes a ``match_hostname()`` function
for performing this check instead of requiring every application
to implement the check separately.

This backport brings ``match_hostname()`` to users
of earlier versions of Python.
Simply make this distribution a dependency of your package,
and then use it like this::

    from backports.ssl_match_hostname import match_hostname, CertificateError
    ...
    sslsock = ssl.wrap_socket(sock, ssl_version=ssl.PROTOCOL_SSLv3,
                              cert_reqs=ssl.CERT_REQUIRED, ca_certs=...)
    try:
        match_hostname(sslsock.getpeercert(), hostname)
    except CertificateError, ce:
        ...

%prep
%setup -q -n backports.ssl_match_hostname-%{version}

%build
%python_build

%install
%python_install
%python_expand rm %{buildroot}%{$python_sitelib}/backports/__init__.py*
%python_expand rm -rf %{buildroot}%{$python_sitelib}/backports/__pycache__/
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%defattr(-,root,root,-)
%doc backports/ssl_match_hostname/README.txt
%doc backports/ssl_match_hostname/LICENSE.txt
%dir %{python_sitelib}/backports/
%{python_sitelib}/backports/ssl_match_hostname/
%{python_sitelib}/backports.ssl_match_hostname-%{version}-py*.egg-info

%changelog
* Thu Aug  3 2017 toddrme2178@gmail.com
- Support python3 for python < 3.5
* Fri Mar 31 2017 toddrme2178@gmail.com
-  %%{python_sitelib}/backports is a namespace package, and so under
  python 2.x it must have a proper
  %%{python_sitelib}/backports/__init__.py file.
  python-backports provides this __init__.py to prevent backports
  packages from conflicting.
  Please see the following links for more details:
    https://pypi.python.org/pypi/backports/
    https://www.python.org/dev/peps/pep-0420/%%23namespace-packages-today
* Fri Mar 31 2017 tbechtold@suse.com
- Remove not needed Requires and BuildRequires for python-backports
* Fri Mar 31 2017 toddrme2178@gmail.com
- Add python2 provides.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Use the common __init__.py used by the python-backports package
  to avoid conflicts.
* Mon Apr 25 2016 freitag@owncloud.com
- Update to upstream version 3.5.0.1
* Tue May 20 2014 toddrme2178@gmail.com
- Initial version
